%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             Dioxygenase and catechol reacting v.2           %
%                    Anita and Piotr                          %
%                  03th September 2010                        %
% It is improvement on model_pre_a.m as the program models    %
% the whole 1-step amplification. It implements transformation%
% of colourless catechol into colourful product.              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p_prime = catechol(time, p)
%% Abbreviations used
%p(1) = [D] = [Dioxygenase]
%p(2) = [C] = [catechol]
%p(3) = [C-D] = [catechol-Dioxygenase]
%p(4) = [M_a] = [Muconic acid - colour]
%% Reaction
%       -k1->
% D + C <---> C-D -k3-> M_a + D
%       <-k2-

%% Units
% [p_prime] = [mol*dm^-3*s^-1]
% [d_d] = [s^-1]
% [p] = [mol*dm^-3]

%% Declaring global variables
global s_sd %production rate constant of splitDioxygenase
global deg_c %common degradation constant due to cell division
global k_d %k_cat value of dioxygenase acting on the substrate

%% Reaction constants
k1 = 1e9; % [dm^3*(mol*s)^-1]
k2 = 1e4; % [s^-1]
k3 = k_d; % [s^-1]

s_d = s_sd;% prodn rate of dioxygenase by transcription and translation is assumed to be of the same value as production of split species
d_d = deg_c;      %degradation rate constant of D

d_c = deg_c;   %degradation rate constant of C
d_cd = 0;  %degradation rate constant of C-D (very quick reaction)
d_M_a = 0;    %degradation rate constant of M_a (very stable chemical and 
              %is allowed to diffuse across cellular membranes, so it is 
              %not depdenent on cell division.

p_prime = zeros(4,1);
%% Equations
%Production rate of D
p_prime(1) = -k1*p(1)*p(2) + (k2+k3)*p(3) + s_d - d_d*p(1);     
%Production rate of C
p_prime(2) = -k1*p(1)*p(2) + k2*p(3) - d_c*p(2);        
%Production rate of C-D
p_prime(3) = k1*p(1)*p(2) - (k2+k3)*p(3) - d_cd*p(3);      
%Production rate of M_a
p_prime(4) = k3*p(3) - d_M_a*p(4);                
end