%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             Dioxygenase and catechol reacting v.2           %
%                    Anita and Piotr                          %
%                  03th September 2010                        %
% It is improvement on model_a.m as the program models        %
% the whole 2-step amplification. It implements transformation%
% of colourless catechol into colourful product.              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function p_prime = catechol_A(time, p)
%% Abbreviations used
%p(1) = [T] = [TEV]
%p(2) = [sD] = [splitDioxygenase]
%p(3) = [T-sD] = [TEV-splitDioxygenase]
%p(4) = [D] = [Dioxygenase]
%p(5) = [C] = [catechol]
%p(6) = [C-D] = [catechol-Dioxygenase]
%p(7) = [M_a] = [Muconic acid - colour]
%% Reactions
% Reaction 1:
%          -k1->
% Tev + sD <---> T-sD -k3-> Tev + D
%          <-k2-
% Reaction 2:
%       -k4->
% D + C <---> C-D -k6-> M_a + D
%       <-k5-

%% Units
% [p_prime] = [mol*dm^-3*s^-1]
% [s_d] = [mol*dm^-3*s^-1]
% [d_d] = [s^-1]
% [p] = [mol*dm^-3]

%% Declaring global variables
global s_sd %production rate constant of splitDioxygenase
global s_t %production rate constant of TEV
global deg_c %common degradation constant due to cell division
global k_TEV %k_cat value of TEV protease acting on the substrate
global k_d %k_cat value of dioxygenase acting on the substrate

%% Reaction constants
k1 = 1e7;  % [dm^3*(mol*s)^-1]
k2 = 610;  % [s^-1]
k3 = k_TEV; % [s^-1]
k4 = 1e9;  % [dm^3*(mol*s)^-1]
k5 = 1e4;  % [s^-1]
k6 = k_d;   % [s^-1]

d_t = deg_c;      %degradation rate constant of TEV
d_sd = deg_c;   %degradation rate constant od splitDioxygenase
d_d = deg_c;      %degradation rate constant of D
d_tsd = deg_c;  %degradation rate constant of TEV-splitDioxygenase
d_c = deg_c;   %degradation rate constant of C
d_cd = 0;  %degradation rate constant of C-D (very quick reaction)
d_M_a = 0;    %degradation rate constant of M_a (very stable chemical and 
              %is allowed to diffuse across cellular membranes, so it is 
              %not depdenent on cell division.

p_prime = zeros(7,1);
%% Model A Equations with production rates remain as cells are assumed alive
%Production rate of TEV
p_prime(1) = -k1*p(1)*p(2) + (k2+k3)*p(3) + s_t - d_t*p(1);     
%Production rate of sD
p_prime(2) = -k1*p(1)*p(2) + k2*p(3) + s_sd - d_sd*p(2);        
%Production rate of T-sD
p_prime(3) = k1*p(1)*p(2) - (k2+k3)*p(3) - d_tsd*p(3);      
%% Common term for both
%Production rate of D
p_prime(4) = k3*p(3) -k4*p(4)*p(5) + (k5+k6)*p(6) - d_d*p(4);    
%% Catechol equations
%Production rate of C
p_prime(5) = -k4*p(4)*p(5) + k5*p(6) - d_c*p(5);        
%Production rate of C-D
p_prime(6) = k4*p(4)*p(5) - (k5+k6)*p(6);      
%Production rate of M_a
p_prime(7) = k6*p(6) - d_M_a*p(7);                

end