%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             Dioxygenase and catechol reacting v.2           %
%                    Anita and Piotr                          %
%                  03th September 2010                        %
% It is improvement on model_b.m as the program models        %
% the whole 3-step amplification. It implements transformation%
% of colourless catechol into colourful product.              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function p_prime = catechol_B(time,p)
%% Abbreviations
%p(1) = [T] = [TEV]
%p(2) = [sD] = [splitDioxygenase]
%p(3) = [T-sD] = [TEV-splitDioxygenase]
%p(4) = [D] = [Dioxygenase]
%p(5) = [sTa] = [splitTEV(a)]
%p(6) = [sTb] = [splitTEV(b)]
%p(7) = [Tsa] = [activated TEV(a)]
%p(8) = [Tsb] = [activated TEV(b)]
%p(9) = [Ts] = [activated TEV]
%p(10) = [T-sTa] = [TEV-splitTEV(a)]
%p(11) = [T-sTb] = [TEV-splitTEV(b)]
%p(12) = [Ts-sD] = [transition state Ts-sD]
%p(13) = [C] = [catechol]
%p(14) = [C-D] = [catechol-Dioxygenase]
%p(15) = [M_a] = [Muconic acid - colour]
%% Units
% [p_dprime] = [mol*dm^-3*s^-1]
% [s_d] = [mol*dm^-3*s^-1]
% [d_d] = [s^-1]
% [p_d] = [mol*dm^-3]

%% Declaring global variables
global s_sd %production rate constant of splitDioxygenase
global s_t %production rate constant of TEV
global deg_c %common degradation constant due to cell division
global k_TEV %k_cat value of TEV protease acting on the substrate
global k_d %k_cat value of dioxygenase acting on the substrate

%% Production and Degradation constants
s_sTa = s_t/1.889;  %production rate constant of sTa
s_sTb = s_t/1.889;  %production rate constant of sTb

d_t = deg_c;    %degradation rate constant of T
d_sTa = deg_c;  %degradation rate constant of sTa
d_sTb = deg_c;  %degradation rate constant of sTb
d_Tsa = deg_c;  %degradation rate constant od Tsa
d_Tsb = deg_c;  %degradation rate constant od Tsb
d_sd = deg_c;   %degradation rate constant of sD
d_ts = deg_c;   %degradation rate cpnstant of Ts 
d_d = deg_c;    %degradation rate constant of D

%% Kinetic rate constants

% 1) T+sTa+sTb+sD <-> T-sD -> T+D+sTa+sTb
k011 = 1e7; % T + sD -> T-sD 
k012 = 610; % T + sD <- T-sD
k013 = k_TEV; % T-sD -> T + D
% 2) T + sTa + sTb + sD -- T-sTa --> T + Tsa + sTb + sD
k021 = 1e7; % T + sTa -> T-sTa
k022 = 610; % T + sTa <- T-sTa
k023 = k_TEV; % T-sTa -> T + Tsa
% 3) T + Tsa + sTb + D --  T-sTb --> T + Tsa + Tsb + D
k031 = 1e7; % T + sTb -> T-sTb
k032 = 610; % T + sTb <- T-sTb
k033 = k_TEV; % T-sTb -> T + Tsb
% 4) Ts + T + sD -- Ts-sD --> Ts + T + D
k041 = 0.4*k011; % Ts + sD -> Ts-sD
k042 = 1.4*k012; % Ts + sD <- Ts-sD
k043 = 0.4*k_TEV; % Ts-sD -> Ts + D
% 5) T + Tsa + Tsb + D --  Tsa-Tsb --> T + Ts + D
k051 = 100; % Tsa + Tsb -> Ts  % !! This is made up !!
k052 = 0.1; % Tsa + Tsb <- Ts  % !! This is made up !!


p_prime = zeros(15,1);
%% Model B Equations without production rates
p_prime(1) = -k011*p(1)*p(2) + (k012+k013)*p(3)-k021*p(1)*p(5) + (k022+k023)*p(10) -k031*p(1)*p(6) + (k032+k033)*p(11) + s_t - d_t*p(1);   %Production rate of TEV
p_prime(2) = -k011*p(1)*p(2) + k012*p(3)-k041*p(9)*p(2) + k042*p(12) + s_sd - d_sd*p(2);
p_prime(3) = k011*p(1)*p(2) - (k012+k013)*p(3); % Negligible degradation term for transition state
p_prime(5) = -k021*p(1)*p(5) + k022*p(10) + s_sTa - d_sTa*p(5);
p_prime(6) = -k031*p(1)*p(6) + k032*p(11) + s_sTb - d_sTb*p(6);
p_prime(7) = k023*p(10)-k051*p(7)*p(8) + k052*p(9) - d_Tsa*p(7); 
p_prime(8) = k033*p(11) -k051*p(7)*p(8) + k052*p(9)- d_Tsb*p(8); 
p_prime(9) = k051*p(7)*p(8) - k052*p(9) -k041*p(9)*p(2) + (k042+k043)*p(12) - d_ts*p(9);
p_prime(10) = k021*p(1)*p(5) - (k022+k023)*p(10); % Negligible degradation term for transition state
p_prime(11) = k031*p(1)*p(6) - (k032+k033)*p(11); % Negligible degradation term for transition state
p_prime(12) = k041*p(9)*p(2) - (k042+k043)*p(12); % Negligible degradation term for transition state

%% Reaction constants for cathecol equations
k1 = 1e9;
k2 = 1e4;
k3 = k_d;

d_c = deg_c;   % degradation rate constant of C
d_cd = 0;  % degradation rate constant of C-D (very quick reaction)
d_M_a = 0;    %degradation rate constant of M_a (very stable chemical and 
              %is allowed to diffuse across cellular membranes, so it is 
              %not depdenent on cell division.

%% Common equtions

% Production of D
p_prime(4) = k013*p(3)+ k043*p(12) -k1*p(4)*p(13) + (k2+k3)*p(14) - d_d*p(4);

%% Catechol equations    
%Production rate of C
p_prime(13) = -k1*p(4)*p(13) + k2*p(14) - d_c*p(13);        
%Production rate of C-D
p_prime(14) = k1*p(4)*p(13) - (k2+k3)*p(14);      
%Production rate of M_a
p_prime(15) = k3*p(14) - d_M_a*p(15);                

end