%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                        Model A                            %
%                Kyasha, Piotr and Anita                    %
%                    20th August 2010                       %
% Program simulating designed 2-step amplification up to    %
% dioxygenase output which includes enzymatic reaction of   %
% TEV on inactive dioxygenase.                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function p_prime = model_a(time, p)

%% Abbreviations used
%p(1) = [T] = [TEV]
%p(2) = [sD] = [splitDioxygenase]
%p(3) = [T-sD] = [TEV-splitDioxygenase]
%p(4) = [D] = [Dioxygenase]

%% Reaction
%          -k1->
% Tev + sD <---> T-sD -k3-> Tev + D
%          <-k2-

%% Units
% [p_prime] = [mol*dm^-3*s^-1]
% [s_d] = [mol*dm^-3*s^-1]
% [d_d] = [s^-1]
% [p] = [mol*dm^-3]

%% Declaring global variables
global s_sd %production rate constant of splitDioxygenase
global s_t %production rate constant of TEV
global deg_c %common degradation constant due to cell division
global k_TEV %k_cat value of TEV protease acting on the substrate

%% Reaction constants
k1 = 1e7; % [dm^3*(mol*s)^-1]
k2 = 610; % [s^-1]
k3 = k_TEV; % [s^-1]

d_t = deg_c;      %degradation rate constant of TEV
d_sd = deg_c;   %degradation rate constant od splitDioxygenase
d_tsd = deg_c;  %degradation rate constant of TEV-splitDioxygenase
d_d = deg_c;    %degradation rate constant of Dioxygenase

p_prime = zeros(4,1);
%% Equations
%Production rate of TEV
p_prime(1) = -k1*p(1)*p(2) + (k2+k3)*p(3) + s_t - d_t*p(1);     
%Production rate of sD
p_prime(2) = -k1*p(1)*p(2) + k2*p(3) + s_sd - d_sd*p(2);        
%Production rate of T-sD
p_prime(3) = k1*p(1)*p(2) - (k2+k3)*p(3); % Negligible degradation term for transition state      
%Production rate of D
p_prime(4) = k3*p(3) - d_d*p(4);                

end